;; Generated package description from yaml-mode.el  -*- no-byte-compile: t -*-
(define-package "yaml-mode" "0.0.16" "Major mode for editing YAML files" '((emacs "24.1")) :commit "6bb9e7f6e1c9224f743a8a68bc210d10eb8cb788" :authors '(("Yoshiki Kurihara" . "clouder@gmail.com") ("Marshall T. Vandegrift" . "llasram@gmail.com")) :maintainer '("Vasilij Schneidermann" . "mail@vasilij.de") :keywords '("data" "yaml") :url "https://github.com/yoshiki/yaml-mode")
